Module map
dotzuki_
engine
0.1.0
Module map
Module Items
Structs
Traits
In crate dotzuki_
engine
dotzuki_engine
Module
map
Structs

MapConnection
Describes a connection between two maps on the overworld.
Traits

MapProvider
Provider trait that supplies map data to the engine.
MapTrait
Marker trait for map identifiers.