#[non_exhaustive]pub struct BorderStyle {
pub corner_tl: u16,
pub corner_tr: u16,
pub corner_bl: u16,
pub corner_br: u16,
pub edge_top: u16,
pub edge_bottom: u16,
pub edge_left: u16,
pub edge_right: u16,
pub fill_bg: u16,
}Expand description
A configurable 9-slot border for menus. Each slot references a tile index in the currently active tileset. Editors can swap these to change the visual style without code changes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.corner_tl: u16corner_tr: u16corner_bl: u16corner_br: u16edge_top: u16edge_bottom: u16edge_left: u16edge_right: u16fill_bg: u16Trait Implementations
Sourceimpl Clone for BorderStyle
impl Clone for BorderStyle
Sourcefn clone(&self) -> BorderStyle
fn clone(&self) -> BorderStyle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BorderStyle
impl Debug for BorderStyle
Sourceimpl Default for BorderStyle
impl Default for BorderStyle
Sourceimpl PartialEq for BorderStyle
impl PartialEq for BorderStyle
impl StructuralPartialEq for BorderStyle