#[non_exhaustive]pub struct CursorStyle {
pub tile: Option<u16>,
pub anchor: CursorAnchor,
}Expand description
Cursor indicator style for menus.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tile: Option<u16>Tile index for the cursor glyph. None → invisible cursor.
anchor: CursorAnchorHow the cursor is positioned relative to the menu entry.
Implementations
Sourceimpl CursorStyle
impl CursorStyle
Sourcepub fn new(tile: Option<u16>, anchor: CursorAnchor) -> Self
pub fn new(tile: Option<u16>, anchor: CursorAnchor) -> Self
Create a cursor style with the given tile index and anchor.