pub struct EdgeInsets {
pub top: u32,
pub bottom: u32,
pub left: u32,
pub right: u32,
}Expand description
Padding inside a menu container (in tiles).
Fields
top: u32Padding from the top of the container (in tiles).
bottom: u32Padding from the bottom of the container (in tiles).
left: u32Padding from the left side of the container (in tiles).
right: u32Padding from the right side of the container (in tiles).