#[non_exhaustive]pub struct PlayerState {
pub x: u16,
pub y: u16,
pub facing: Direction,
pub movement_state: MovementState,
pub transport: TransportMode,
pub bike_speedup_active: bool,
}Expand description
Runtime player state in the overworld.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.x: u16y: u16facing: Directionmovement_state: MovementStatetransport: TransportModebike_speedup_active: boolWhether biking advances at double speed (the classic bike speedup). Defaults to on; a game can switch it off for specific rules (e.g. a steep slope cancels the speedup while the player presses UP/LEFT/RIGHT).