pub enum DialogMode {
Typing,
Paused,
WaitingForInput,
Scrolling,
Done,
}Expand description
The current operational mode of the dialog engine.
Variants
Typing
Characters are being typed out, one per frame.
Paused
The text engine is paused (e.g. a TX_PAUSE delay).
WaitingForInput
Waiting for the player to press A to continue.
Scrolling
Waiting for the player to press A after a scroll prompt.
Done
The dialog has ended.