Module tile_meta
dotzuki_
engine
0.1.0
Module tile_
meta
Module Items
Enums
Traits
In crate dotzuki_
engine
dotzuki_engine
Module
tile_
meta
Enums

Collision
Type
Describes how a tile interacts with entities on the overworld map.
Traits

Tile
Meta
Trait
Marker trait for tile metadata identifiers.
Tile
Metadata
Provides collision and terrain metadata for tiles in a given tileset.