Module map

Module map 

Structs

MapConnection
Describes a connection between two maps on the overworld.

Traits

MapProvider
Provider trait that supplies map data to the engine.
MapTrait
Marker trait for map identifiers.