#[non_exhaustive]pub struct WarpPoint<M: MapTrait> {
pub x: u8,
pub y: u8,
pub target_map: M,
pub target_warp_id: u8,
pub is_last_map: bool,
}Expand description
A warp point within a map (door, staircase, etc.).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.x: u8Position in the map (block coordinates).
y: u8target_map: MTarget map to warp to.
target_warp_id: u8Index of the target warp in the destination map.
is_last_map: boolWhether this warp sends the player back to the last-visited map.
Implementations